package com.ruoyi.warehouse.check.service;

import java.util.List;
import com.ruoyi.warehouse.check.domain.TWarehouseCheckItems;

/**
 * 巡检check-itemService接口
 * 
 * @author dongyongwei
 * @date 2021-07-21
 */
public interface ITWarehouseCheckItemsService 
{
    /**
     * 查询巡检check-item
     * 
     * @param fId 巡检check-itemID
     * @return 巡检check-item
     */
    public TWarehouseCheckItems selectTWarehouseCheckItemsById(Long fId);

    /**
     * 查询巡检check-item列表
     * 
     * @param tWarehouseCheckItems 巡检check-item
     * @return 巡检check-item集合
     */
    public List<TWarehouseCheckItems> selectTWarehouseCheckItemsList(TWarehouseCheckItems tWarehouseCheckItems);

    /**
     * 新增巡检check-item
     * 
     * @param tWarehouseCheckItems 巡检check-item
     * @return 结果
     */
    public int insertTWarehouseCheckItems(TWarehouseCheckItems tWarehouseCheckItems);

    /**
     * 修改巡检check-item
     * 
     * @param tWarehouseCheckItems 巡检check-item
     * @return 结果
     */
    public int updateTWarehouseCheckItems(TWarehouseCheckItems tWarehouseCheckItems);

    /**
     * 批量删除巡检check-item
     * 
     * @param fIds 需要删除的巡检check-itemID
     * @return 结果
     */
    public int deleteTWarehouseCheckItemsByIds(Long[] fIds);

    /**
     * 删除巡检check-item信息
     * 
     * @param fId 巡检check-itemID
     * @return 结果
     */
    public int deleteTWarehouseCheckItemsById(Long fId);

    /**
     * app查询巡检模块
     * @param tWarehouseCheckItems
     * @return
     */
    public List<TWarehouseCheckItems> appListByUser(TWarehouseCheckItems tWarehouseCheckItems);
}
